#
# spec file for package qt5ct
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qt5ct
Version:        1.8
Release:        1.4
Summary:        Qt5 Configuration Tool
License:        BSD-2-Clause
URL:            https://sourceforge.net/projects/qt5ct
Source:         https://downloads.sf.net/qt5ct/%{name}-%{version}.tar.bz2
Source1:        qt5ct.sh
Source2:        qt5ct.csh
BuildRequires:  gcc-c++
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5PlatformSupport-private-headers-devel
BuildRequires:  libQt5Widgets-private-headers-devel
BuildRequires:  libqt5-qtpaths
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5ThemeSupport)
BuildRequires:  cmake(Qt5Widgets)
%requires_eq    libQt5Gui5
# libqt5-qtct was last used in openSUSE Leap 42.1.
Provides:       libqt5-qtct = %{version}
Obsoletes:      libqt5-qtct < %{version}

%description
This applications allows users to configure Qt5 settings (theme, font,
icons, etc.) under DE/WM without Qt integration.

%prep
%autosetup -p1

%build
%cmake

%cmake_build

%install
%cmake_install

install -Dpm 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/profile.d/qt5ct.sh
install -Dpm 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/profile.d/qt5ct.csh

# Unneeded
rm %{buildroot}%{_libdir}/libqt5ct-common.so

%ldconfig_scriptlets

%files
%license COPYING
%doc AUTHORS ChangeLog README
%config %{_sysconfdir}/profile.d/qt5ct.*sh
%{_bindir}/qt5ct
%{_datadir}/applications/qt5ct.desktop
%{_datadir}/qt5ct/
%{_libdir}/libqt5ct-common.*
%dir %{_libdir}/qt5/plugins/platformthemes/
%{_libdir}/qt5/plugins/platformthemes/libqt5ct.so
%dir %{_libdir}/qt5/plugins/styles/
%{_libdir}/qt5/plugins/styles/libqt5ct-style.so

%changelog
* Mon Oct 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.8
  * added XDG desktop portal dialogs support
  * added qt6ct compatibility
  * improved warning about incorrect environment variable
  * improved icon loader
  * only prepend our stylesheet if it has changed
  * fixed compatibility with applications that use own stylesheet
  * fixed some clazy and clang-tidy warnings
  * changed font configuration format
  * added keywords entry to desktop file
  * changed minimal Qt version to 5.15 for cmake build system
  * fixed qmake build
  * fixed localization support
  * improved cmake build
  * fixed parallel build using qmake
  * updated translations
* Mon Mar 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.5
  * fixed cmake support
  * prepend custom stylesheets to the application stylesheet
  * updated Catalan translation
  * updated French translation
  * added troubleshooting settings
  * added Japanese translation
  * updated Dutch translation
  * updated Spanish translation
  * updated Russian translation
  * updated Greek translation
  * fixed build regression
- Use CMake for building qt5ct.
* Sat May  1 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.2:
  * updated color schemes
  * updated Spanish translation
  * updated Dutch translation
  * updated Chinese (Simplified) translation
  * updated Dunish translation
  * updated Italian translation
* Wed Jul 29 2020 Jonas Kvinge <jonas@jkvinge.net>
- Update to 1.1:
  * fixed issue with custom icon themes
  * updated Danish translation (scootergrisen)
* Fri Jul 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.0:
  * added Ia Ora color scheme (from Mandriva default style)
  * disabled debug messages by default
  * fixed Qt 5.15 palette
  * fixed crash on certain applications under Qt 5.15 (boo#1174224)
* Sat Dec  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.41
  * Updated translations
  * added keyboard scheme option
  * added system-wide configuration support
  * added feature to hide shortcuts in context menus
  * fixed issue with cutebrowser
  * fixed global config support
  * using separate thread for icon theme loading
  * replaced deprecated code
  * fixed wayland application id
  * fixed crash on icon theme search (regression since 0.40)
* Sun Dec 30 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.37
  * added Qt 5.12 support
  * added alpha channel for color themes
  * added environment variables support for paths in the
    qt5ct.conf
  * added mime-type based icons in the file dialog
  * fixed icon theme parsing
  * replaced deprecated code
  * updated Russian translation
  * updated Chinese (Taiwan) translation (Jeff Huang)
  * updated Dutch (Netherlands) translation (Heimen Stoffels)
  * updated Greek translation (Dimitrios Glentadakis)
  * updated German translation (Ettore Atalan)
  * updated Danish translation (scootergrisen)
* Mon Oct 22 2018 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.36
  * added feature to start qt5ct application without
    QT_QPA_PLATFORMTHEME environment variable
  * fixed issue with custom palette in some applications
  * fixed build without QtDBus module
  * fixed crash due to conflict between gtk2 style and gtk3 dialogs
  * updated translations
* Thu Mar  8 2018 sor.alexei@meowr.ru
- Update to version 0.35:
  * Add colour themes and style sheets from the Lumina DE.
  * Add some fixes for the Qt Fusion style.
  * Add a feature to use GTK+/KDE dialogues (requires Qt 5.9 or
    higher).
  * Add a feature to copy style sheets.
  * Add some error messages.
  * Add a feature to compile without D-Bus support.
  * Fix style sheet list editing.
  * Fix tab order.
  * Update Russian, Greek, Dutch (Netherlands), German, Danish,
    Chinese (Taiwan), Bulgarian, Czech translations.
* Sat Jan 27 2018 aloisio@gmx.com
- Update to version 0.34
  * added feature to disable shortcut underlines
  * added Danish translation (scootergrisen)
  * improved global menu checking
  * improved XDG support
  * fixed font settings
  * fixed Qt 5.5 support
  * updated Russian translation
  * updated Czech translation (fri)
  * updated Dutch (Netherlands) translation (Heimen Stoffels)
  * updated Chinese (Taiwan) translation (Jeff Huang)
  * updated German translation (Ettore Atalan)
  * updated Italian translation (Luigi Baldoni)
  * updated Bulgarian translation (Kiril Kirilov)
  * updated Greek translation (Dimitrios Glentadakis)
* Sat Jun  3 2017 aloisio@gmx.com
- Update to version 0.33
  * fixed build without dbus support (coacher)
  * fixed Qt 5.6 support (coacher)
  * updated Hebrew translation (Elkana Birdugo)
  Version 0.32
  * added global menu support
  * updated Czech translation (fri)
  * updated Greek translation (Dimitrios Glentadakis)
  * updated Russian translation
- Changed source URL to https
* Sun Apr 30 2017 lnussel@suse.de
- Don't set QT_QPA_PLATFORMTHEME when running a KDE session to avoid
  overriding the settings defined there (boo#920792).
* Fri Apr 14 2017 sor.alexei@meowr.ru
- Update to version 0.31:
  * Add an option "Toolbar button style".
  * add an option "Mouse wheel scroll lines".
  * Add a test for minimal Qt version.
  * Using C++11 for the source code.
  * Fix Qt 5.4 support.
  * Add Arabic translation.
  * Update Russian, Bulgarian, Dutch (Netherlands),
    Chinese (Taiwan), German, Serbian, Czech translations.
* Fri Mar 24 2017 alarrosa@suse.com
- Update to version 0.30:
  * Fixed crash on nonexistent style in qt5ct.conf
  * Fixed issue with KDE color themes
  * Updated documentation
  * Updated Bulgarian translation
  * Updated French translation
* Wed Jan 25 2017 sor.alexei@meowr.ru
- Update to version 0.29 (changes since 0.27):
  * Add Qt 5.8 support.
  * Add a qt5ct proxy-style plugin.
  * Add a Serbian translation.
  * Updated Bulgarian, Italian, Russian, Dutch (Netherlands), Czech
    German, Chinese (Taiwan), Greek translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 0.27:
  * Add D-Bus tray support.
  * Add a possibility to disable debug output.
  * Update documentation.
* Mon Sep  5 2016 sor.alexei@meowr.ru
- Update to version 0.26:
  * Fix Stellarium compatibility.
  * Update translations.
* Wed Aug 10 2016 sor.alexei@meowr.ru
- Update to version 0.25:
  * Add environment variables verification.
  * Update translations.
* Thu Jun  2 2016 sor.alexei@meowr.ru
- Update to version 0.24:
  * Add a feature to preview the colour scheme on edit.
  * Add icons for some actions.
  * Fix palette editor.
  * Fix documentation.
  * Fix infinite recursion in the icon theme parser.
  * Update Greek translation.
- Require the libQt5Gui5 version qt5ct was built against
  (boo#980881).
* Wed Apr 27 2016 sor.alexei@meowr.ru
- Update to version 0.23:
  * Add support for single line comments in the style sheets.
  * Fix issue with overriding application palette.
  * Update Bulgarian translation.
* Sun Mar  6 2016 sor.alexei@meowr.ru
- Rename libqt5-qtct package to qt5ct to resolve confusion when
  qt5ct was considered a part of Qt.
* Sun Mar  6 2016 sor.alexei@meowr.ru
- Update to 0.22:
  * Disable html mode in the qss editor.
  * Fix issue with overriding stylesheets.
  * Update documentation.
  * Update Italian translation.
  * Add Hebrew translation.
* Fri Jan  8 2016 sor.alexei@meowr.ru
- Update to 0.21:
  * Add option "Activate item on single-click".
  * Add Spanish and Slovak translations.
  * Update Polish, Dutch (Netherlands), Czech, Chinese translations.
* Thu Dec 24 2015 sor.alexei@meowr.ru
- Add a qt5ct dummy package to make it easier to find this package.
* Sun Oct 18 2015 sor.alexei@meowr.ru
- Update to 0.20:
  * Fix widget spacing.
  * Fix typo.
  * Update Bulgarian, Italian translation.
* Thu Sep 24 2015 sor.alexei@meowr.ru
- Update to 0.19:
  * Add feature to save geometry of the style sheet editor.
  * Fix qt5ct.desktop.
  * Update Greek, Czech, Chinese Simplified translations.
* Mon Sep 21 2015 sor.alexei@meowr.ru
- Update to 0.18:
  * Add colour schemes support.
  * Update Dutch (Netherlands), German, Polish, Chinese, Russian
    translations.
* Tue Sep 15 2015 sor.alexei@meowr.ru
- Update to 0.17:
  * Fix crash in QupZilla.
  * Update Greek translation.
* Sun Sep 13 2015 sor.alexei@meowr.ru
- Update to 0.16:
  * Add feature to save palette editor geometry.
  * Change palette editor layout.
  * Update Chinese Simplified translation.
* Sun Sep  6 2015 sor.alexei@meowr.ru
- Update to 0.15 (changes since 0.13):
  * Add option "Dialog buttons have icons".
  * Add option "Menus have icons".
  * Fix style and palette initialisation.
  * Fix problem with qtcurve style.
  * Update Russian, German, Dutch (Netherlands), Chinese (Taiwan),
    Czech translations.
* Sun Aug 23 2015 sor.alexei@meowr.ru
- Update to 0.13:
  * Add $XDG_DATA_HOME support.
  * Add Italian translation.
* Sat May 30 2015 sor.alexei@meowr.ru
- Update to 0.12:
  * Fix infinite loop in the icon theme parser.
  * Add Chinese Simplified translation.
* Tue May 12 2015 sor.alexei@meowr.ru
- Update to 0.11:
  * Use less private headers.
  * Improve build scripts.
  * Fix settings updating issue.
  * Fix font setting.
  * Fix fonts.conf generation.
  * Fix segmentation fault on "widget-less" applications.
  * Add Polish translation.
  * Update German translation.
* Mon Mar 30 2015 sor.alexei@meowr.ru
- Update to 0.10:
  * Add more debug messages.
  * Fix qss path.
  * Add Greek translation.
* Tue Mar 10 2015 sor.alexei@meowr.ru
- Update to 0.9:
  * Add more user friendly colour roles.
  * Add feature to disable qss support.
  * Add Dutch (Netherlands) translation.
  * Update Chinese (Taiwan), Czech, Bulgarian, German, Russian
    translations.
* Thu Feb 12 2015 sor.alexei@meowr.ru
- Update to 0.8:
  * Improve icon theme parsing.
  * Add Bulgarian translation.
  * Fix plugin metadata.
  * Fix font updating issue.
  * Fix Russian translation.
* Sat Feb  7 2015 sor.alexei@meowr.ru
- Update to 0.7:
  * Add feature to rename style sheet.
  * Add context menu to the style sheet list.
  * Add feature to apply theme for running applications.
  * Add Chinese (Taiwan) translation.
  * Add Czech translation.
  * Add German translation.
  * Update Russian translation.
* Tue Jan 20 2015 sor.alexei@meowr.ru
- Update to 0.6:
  * Add style sheet settings.
  * Add transifex integration.
  * Update Russian translation.
* Mon Jan  5 2015 sor.alexei@meowr.ru
- Update to 0.5:
  * Add dialog buttons layout setting.
  * Add feature to change install prefix.
  * Update Russian translation.
* Mon Dec 22 2014 sor.alexei@meowr.ru
- Update to 0.4:
  * Add font config generation.
  * Fix segmentation fault in the preview window.
  * Update Russian translation.
* Mon Dec 15 2014 sor.alexei@meowr.ru
- Initial build.
